@@ -7,13 +7,10 @@ use Moose;
 use namespace::autoclean;
 
 # document properties
-extends 'XML::NewsML_G2::AnyItem';
+extends 'XML::NewsML_G2::Substancial_Item';
 
-has 'title', isa => 'Str', is => 'ro', required => 1;
-has 'subtitle',   isa => 'Str',               is => 'rw';
 has 'caption',    isa => 'Str',               is => 'rw';
 has 'teaser',     isa => 'Str',               is => 'rw';
-has 'summary',    isa => 'Str',               is => 'rw';
 has 'byline',     isa => 'Str',               is => 'rw';
 has 'dateline',   isa => 'Str',               is => 'rw';
 has 'paragraphs', isa => 'XML::LibXML::Node', is => 'rw';
@@ -31,6 +28,13 @@ has 'slugline',     isa => 'Str', is => 'rw';
 has 'slugline_sep', isa => 'Str', is => 'rw', default => '/';
 has 'electiondistrict', isa => 'XML::NewsML_G2::ElectionDistrict', is => 'rw';
 
+has 'event_references',
+    isa     => 'ArrayRef[XML::NewsML_G2::Event_Ref]',
+    is      => 'rw',
+    default => sub { [] },
+    traits  => ['Array'],
+    handles =>
+    { add_event_reference => 'push', has_event_references => 'count' };
 has 'sources',
     isa     => 'ArrayRef[Str]',
     is      => 'rw',
@@ -87,18 +91,6 @@ has 'desks',
     default => sub { [] },
     traits  => ['Array'],
     handles => { add_desk => 'push', has_desks => 'count' };
-has 'media_topics',
-    isa     => 'HashRef[XML::NewsML_G2::Media_Topic]',
-    is      => 'rw',
-    default => sub { {} },
-    traits  => ['Hash'],
-    handles => { has_media_topics => 'count' };
-has 'concepts',
-    isa     => 'HashRef[XML::NewsML_G2::Concept]',
-    is      => 'rw',
-    default => sub { {} },
-    traits  => ['Hash'],
-    handles => { has_concepts => 'count' };
 has 'locations',
     isa     => 'HashRef[XML::NewsML_G2::Location]',
     is      => 'rw',
@@ -125,26 +117,12 @@ has 'inlinedata',
     handles => { add_inlinedata => 'push', has_inlinedata => 'count' };
 
 sub _build_content_created {
-    return DateTime->now( time_zone => 'local' );
+    my ($self) = @_;
+    return DateTime->now( time_zone => $self->timezone );
 }
 
 # public methods
 
-sub add_media_topic {
-    my ( $self, $mt ) = @_;
-    return if exists $self->media_topics->{ $mt->qcode };
-    $self->media_topics->{ $mt->qcode } = $mt;
-    $self->add_media_topic( $mt->parent ) if ( $mt->parent );
-    return 1;
-}
-
-sub add_concept {
-    my ( $self, $concept ) = @_;
-    return if exists $self->concepts->{ $concept->uid };
-    $self->concepts->{ $concept->uid } = $concept;
-    return 1;
-}
-
 sub add_location {
     my ( $self, $l ) = @_;
     return if exists $self->locations->{ $l->qcode };
@@ -264,6 +242,10 @@ DateTime instance
 
 additional text for specifying details on the embargo
 
+=item event_references
+
+List of XML::NewsML_G2::Event_Ref instances
+
 =item evolved_froms
 
 List of  XML::NewsML_G2::Link instances
@@ -419,6 +401,10 @@ XML::NewsML_G2::Link instance
 
 Add a L<XML::NewsML_G2::Desk> instance
 
+=item add_event_reference
+
+Add a L<XML::NewsML_G2::Event_Ref> instance
+
 =item add_genre
 
 Add a L<XML::NewsML_G2::Genre> instance
