@@ -2,6 +2,7 @@ package XML::NewsML_G2::Writer::News_Message;
 
 use XML::NewsML_G2::Writer::News_Item;
 use XML::NewsML_G2::Writer::Package_Item;
+use XML::NewsML_G2::Writer::Event_Item;
 
 use Moose;
 use List::MoreUtils qw(uniq);
@@ -63,6 +64,13 @@ sub _create_itemSet {
                 g2_version     => $self->g2_version
             );
         }
+        elsif ( $item->isa('XML::NewsML_G2::Event_Item') ) {
+            $writer = XML::NewsML_G2::Writer::Event_Item->new(
+                event_item     => $item,
+                scheme_manager => $self->scheme_manager,
+                g2_version     => $self->g2_version
+            );
+        }
 
         $item_set->appendChild( $writer->create_dom()->documentElement() );
     }
